<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Local plugin "Hsh modified Boost course overview on campus" - Settings
 * Original: local_boostnavigation
 *
 * @package    local_hsh_boostnavigation
 * @copyright  2017 Alexander Bias, Ulm University <alexander.bias@uni-ulm.de>, Edited by Tobias Baden, Hochschule Hannover
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die();
require_once(__DIR__ . '/lib.php');

if ($hassiteconfig) {
    // New settings page.
    $page = new admin_settingpage('local_hsh_boostnavigation',
        get_string('pluginname', 'local_hsh_boostnavigation', null, true));

    if ($ADMIN->fulltree) {
        // Default-Settings auf 0 da ein aktueller Bug besteht, der die Default-Settings nicht übernimmt.
        $setting = new admin_setting_configtext('local_hsh_boostnavigation/settings_nodescount',
            get_string('settings_nodescount', 'local_hsh_boostnavigation', null, true),
            get_string('settings_nodescount_desc', 'local_hsh_boostnavigation', null, true), 0, PARAM_INT);
        $page->add($setting);

        // Default-Settings auf 0 da ein aktueller Bug besteht, der die Default-Settings nicht übernimmt.
        $page->add(new admin_setting_configcheckbox('local_hsh_boostnavigation/settings_showunabhaengignode',
            get_string('settings_unabhaengig', 'local_hsh_boostnavigation', null, true),
            get_string('settings_unabhaengig_desc', 'local_hsh_boostnavigation', null, true),
            0));

        // Default-Settings auf 0 da ein aktueller Bug besteht, der die Default-Settings nicht übernimmt.
        $page->add(new admin_setting_configcheckbox('local_hsh_boostnavigation/settings_opennewestsemester',
            get_string('settings_opennewestsemester', 'local_hsh_boostnavigation', null, true),
            get_string('settings_opennewestsemester_desc', 'local_hsh_boostnavigation', null, true),
            0));

        // Auswahl für die Semesterreihenfolge
        $name = 'local_hsh_boostnavigation/settings_semesterorder';
        $title = get_string('settings_semesterorder', 'local_hsh_boostnavigation');
        $description = get_string('settings_semesterorder_desc', 'local_hsh_boostnavigation');
        $choices[0] = 'Neueste Oben';
        $choices[1] = 'Neueste Unten';
        $setting = new admin_setting_configselect($name, $title, $description, null, $choices);
        $setting->set_updatedcallback('theme_reset_all_caches');
        $page->add($setting);

        // Auswahl für die Semesterreihenfolge - Semesterunabhängige Kurse
        $name = 'local_hsh_boostnavigation/settings_unabhaengigposition';
        $title = get_string('settings_unabhaengigposition', 'local_hsh_boostnavigation');
        $description = get_string('settings_unabhaengigposition_desc', 'local_hsh_boostnavigation');
        $choices[0] = 'Oberhalb der Semester';
        $choices[1] = 'Unterhalb der Semester';
        $setting = new admin_setting_configselect($name, $title, $description, null, $choices);
        $setting->set_updatedcallback('theme_reset_all_caches');
        $page->add($setting);
    }

    // Add settings page to the appearance settings category.
    $ADMIN->add('appearance', $page);
}
